# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['pyskroutz', 'pyskroutz.models', 'pyskroutz.resources']

package_data = \
{'': ['*']}

install_requires = \
['pydantic[email]>=1.8.2,<2.0.0',
 'requests>=2.25.1,<3.0.0',
 'typing-extensions>=3.10.0,<4.0.0']

setup_kwargs = {
    'name': 'pyskroutz',
    'version': '0.1.11',
    'description': 'A Python client for Skroutz API.',
    'long_description': '<div align="center">\n    <h1>pyskroutz</h1>\n    <p>A Python client for <a href="https://developer.skroutz.gr/api/v3/">Skroutz API</a>.</p>\n    <img src="https://github.com/sp1thas/pyskroutz/workflows/testing/badge.svg" alt="testing badge">\n    <img src="https://github.com/sp1thas/pyskroutz/workflows/build/badge.svg" alt="build badge">\n    <img src="https://readthedocs.org/projects/pyskroutz/badge/?version=latest" alt="docs badge">\n    <a href="https://pypi.python.org/pypi/pyskroutz/">\n        <img src="https://img.shields.io/pypi/v/pyskroutz.svg" alt="pypi badge" />\n    </a>\n    <a href="https://codecov.io/gh/sp1thas/pyskroutz">\n        <img alt="code coverage badge" src="https://codecov.io/gh/sp1thas/pyskroutz/branch/master/graph/badge.svg?token=WTYZU0ENYX" />\n    </a>\n    <img src="https://img.shields.io/badge/code%20style-black-black">\n</div>\n<hr>\n\n\n## Installation\n```bash\npip install pyskroutz\n```\n\n## Usage\n\nFirst of all, you have to initiate an client in order to interact with Skroutz API. Make sure that you have a valid pair of client id and client secret. From now on, `client` will be the following object.\n\n```python\nimport pyskroutz\nclient = pyskroutz.client(\'<client-id>\', \'<client-secret>\')\n```\n\nThe `client` object will be passed as parameter in order to retrieve data from a resource\'s endpoint.\n\n### Search\n\n```python\nresults = pyskroutz.search(client)("iphone").execute()\n```\n<details>\n    <summary><code>results</code></summary>\n\n```python\nSearchResultsList(\n    categories=[],\n    meta=SearchMeta(\n        q=None,\n        alternatives=[],\n        strong_matches=StrongMatcheItem(\n            sku=None,\n            manufacturer=ManufacturerItem(\n                id=356,\n                name="Apple",\n                image_url=HttpUrl(\n                    "https://a.scdn.gr/ds/manufacturers/356/20160322115406_ae6f9a87.png",\n                    scheme="https",\n                    host="a.scdn.gr",\n                    tld="gr",\n                    host_type="domain",\n                    path="/ds/manufacturers/356/20160322115406_ae6f9a87.png",\n                ),\n            ),\n        ),\n        pagination=PaginationItem(page=1, per=25, total_pages=0, total_results=0),\n    ),\n)\n```\n</details>\n\n### List Categories\n\n```python\ncategories = pyskroutz.categories(client).get(per=3).execute()\n```\n<details>\n    <summary><code>categories</code></summary>\n\n```python\nCategoryList(\n    categories=[\n        CategoryItem(\n            web_uri=HttpUrl(\n                "https://skroutz.gr/c/1/statherh-tilefwnia.html",\n                scheme="https",\n                host="skroutz.gr",\n                tld="gr",\n                host_type="domain",\n                path="/c/1/statherh-tilefwnia.html",\n            ),\n            id=1,\n            name="Σταθερή Τηλεφωνία",\n            children_count=5,\n            image_url=HttpUrl(\n                "https://c.scdn.gr/ds/categories/1/20171113120915_72fa0f63.jpeg",\n                scheme="https",\n                host="c.scdn.gr",\n                tld="gr",\n                host_type="domain",\n                path="/ds/categories/1/20171113120915_72fa0f63.jpeg",\n            ),\n            parent_id=2,\n            fashion=True,\n            layout_mode="tiles",\n            code="statherh-tilefwnia",\n            path="76,1269,2,1",\n            show_specifications=False,\n            manufacturer_title="Κατασκευαστές",\n        ),\n        CategoryItem(\n            web_uri=HttpUrl(\n                "https://skroutz.gr/c/2/tilefwnia.html",\n                scheme="https",\n                host="skroutz.gr",\n                tld="gr",\n                host_type="domain",\n                path="/c/2/tilefwnia.html",\n            ),\n            id=2,\n            name="Τηλεφωνία",\n            children_count=2,\n            image_url=HttpUrl(\n                "https://b.scdn.gr/ds/categories/2/20171113120916_9d335c35.jpeg",\n                scheme="https",\n                host="b.scdn.gr",\n                tld="gr",\n                host_type="domain",\n                path="/ds/categories/2/20171113120916_9d335c35.jpeg",\n            ),\n            parent_id=1269,\n            fashion=True,\n            layout_mode="tiles",\n            code="tilefwnia",\n            path="76,1269,2",\n            show_specifications=False,\n            manufacturer_title="Κατασκευαστές",\n        ),\n        CategoryItem(\n            web_uri=HttpUrl(\n                "https://skroutz.gr/c/5/photografia-video.html",\n                scheme="https",\n                host="skroutz.gr",\n                tld="gr",\n                host_type="domain",\n                path="/c/5/photografia-video.html",\n            ),\n            id=5,\n            name="Φωτογραφία & Video",\n            children_count=4,\n            image_url=HttpUrl(\n                "https://b.scdn.gr/ds/categories/5/20171113120916_dfd75306.jpeg",\n                scheme="https",\n                host="b.scdn.gr",\n                tld="gr",\n                host_type="domain",\n                path="/ds/categories/5/20171113120916_dfd75306.jpeg",\n            ),\n            parent_id=1269,\n            fashion=True,\n            layout_mode="tiles",\n            code="photografia-video",\n            path="76,1269,5",\n            show_specifications=False,\n            manufacturer_title="Κατασκευαστές",\n        ),\n    ],\n    meta=MetaItemBase(\n        available_filters=None,\n        order_by=None,\n        order_by_methods=None,\n        pagination=PaginationItem(page=1, per=3, total_pages=1251, total_results=3751),\n        personalization=None,\n        sku_rating_breakdown=None,\n        sku_reviews_aggregation=None,\n    ),\n)\n```\n</details>\n\n### Retrieve a book\n\n```python\nbook = pyskroutz.books(client).get(242327).execute()\n```\n<details>\n    <summary><code>book</code></summary>\n\n```python\nBooksRetrieve(\n    book=BookItem(\n        web_uri=HttpUrl(\n            "https://www.skroutz.gr/books/242327.%CE%9F-%CE%A7%CE%AC%CF%81%CE%B9-%CE%A0%CF%8C%CF%84%CE%B5%CF%81-%CE%BA%CE%B1%CE%B9-%CE%B7-%CF%86%CE%B9%CE%BB%CE%BF%CF%83%CE%BF%CF%86%CE%B9%CE%BA%CE%AE-%CE%BB%CE%AF%CE%B8%CE%BF%CF%82.html",\n            scheme="https",\n            host="www.skroutz.gr",\n            tld="gr",\n            host_type="domain",\n            path="/books/242327.%CE%9F-%CE%A7%CE%AC%CF%81%CE%B9-%CE%A0%CF%8C%CF%84%CE%B5%CF%81-%CE%BA%CE%B1%CE%B9-%CE%B7-%CF%86%CE%B9%CE%BB%CE%BF%CF%83%CE%BF%CF%86%CE%B9%CE%BA%CE%AE-%CE%BB%CE%AF%CE%B8%CE%BF%CF%82.html",\n        ),\n        price_max=12.96,\n        price_min=6.61,\n        reviewable=True,\n        reviews_count=15,\n        reviewscore=4.93333,\n        shop_count=42,\n        id=242327,\n        name="Ο Χάρι Πότερ και η φιλοσοφική λίθος",\n        main_author_id=385,\n        main_author="J. K. Rowling",\n        images=ImageItemBase(\n            alternatives=None,\n            main=HttpUrl(\n                "https://b.scdn.gr/images/sku_main_images/000242/242327/medium_20200219102603_o_chari_poter_kai_i_filosofiki_lithos.jpeg",\n                scheme="https",\n                host="b.scdn.gr",\n                tld="gr",\n                host_type="domain",\n                path="/images/sku_main_images/000242/242327/medium_20200219102603_o_chari_poter_kai_i_filosofiki_lithos.jpeg",\n            ),\n        ),\n    )\n)\n```\n</details>\n\nFor further usage details navigate to [API Documentation](https://pyskroutz.readthedocs.io/en/latest/). Almost every endpoint of Skroutz API is supported by this client.\n\n## How to contribute\n\nIf you wish to contribute, check out the [CONTRIBUTING.md](docs/contributing.md) guide for further details.\n',
    'author': 'Panagiotis Simakis',
    'author_email': 'sp1thas@autistici.org',
    'maintainer': 'Panagiotis Simakis',
    'maintainer_email': 'sp1thas@autistici.org',
    'url': 'https://github.com/sp1thas/pyskroutz',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6.2,<4.0',
}


setup(**setup_kwargs)
